@@ -32,6 +32,8 @@ int send_continuation(session *ssn, const char *data, size_t len);
 #define TRY(F)								       \
 	switch ((F)) {							       \
 	case -1:							       \
+		error("unexpected network error for %s@%s\n",		       \
+		    ssn->username, ssn->server);			       \
 		if ((!strcasecmp(get_option_string("recover"), "all") ||       \
 		    !strcasecmp(get_option_string("recover"), "errors")))      \
 			for (;;) {					       \
@@ -45,14 +47,17 @@ int send_continuation(session *ssn, const char *data, size_t len);
 			}						       \
 		return -1;						       \
 	case STATUS_BYE:						       \
+		error("unexpected IMAP BYE for %s@%s\n",		       \
+		    ssn->username, ssn->server);			       \
 		close_connection(ssn);					       \
 		if (!strcasecmp(get_option_string("recover"), "all")) {	       \
 			if (request_login(&ssn, NULL, NULL, NULL, NULL,	       \
 			    NULL, NULL) != -1)				       \
 				return STATUS_NONE;			       \
-		} else							       \
+		} else {						       \
 			session_destroy(ssn);				       \
 			ssn = NULL;					       \
+		}							       \
 		return -1;						       \
 	}
 
@@ -165,7 +170,7 @@ request_login(session **ssnptr, const char *server, const char *port, const
 {
 	int t, r, rg = -1, rl = -1;
 	session *ssn = *ssnptr;
-	
+
 	if (*ssnptr && (*ssnptr)->socket != -1)
 		return STATUS_PREAUTH;
 
@@ -182,8 +187,8 @@ request_login(session **ssnptr, const char *server, const char *port, const
 			ssn->sslproto = ssl;
 	} else {
 		debug("recovering connection: %s://%s@%s:%s/%s\n",
-		    ssn->sslproto ?"imaps" : "imap", ssn->username, ssn->server,
-		    ssn->port, ssn->selected ? ssn->selected : "");
+		    ssn->sslproto ? "imaps" : "imap", ssn->username,
+		    ssn->server, ssn->port, ssn->selected ? ssn->selected : "");
 	}
 
 	if (open_connection(ssn) == -1)
@@ -234,23 +239,6 @@ request_login(session **ssnptr, const char *server, const char *port, const
 			ssn = NULL;
 			return STATUS_NO;
 		}
-		if (rl != STATUS_OK && ssn->password &&
-		    ssn->capabilities & CAPABILITY_CRAMMD5 &&
-		    get_option_boolean("crammd5")) {
-			unsigned char *in, *out;
-			CHECK(t = send_request(ssn, "AUTHENTICATE CRAM-MD5"));
-			CHECK(r = response_authenticate(ssn, t, &in));
-			if (r == STATUS_CONTINUE) {
-				if ((out = auth_cram_md5(ssn->username,
-				    ssn->password, in)) == NULL)
-					goto abort;
-				CHECK(send_continuation(ssn, (char *)(out),
-				    strlen((char *)(out))));
-				xfree(out);
-				CHECK(rl = response_generic(ssn, t));
-			} else
-				goto abort;
-		}
 		if (rl != STATUS_OK && ssn->password) {
 			CHECK(t = send_request(ssn, "LOGIN \"%s\" \"%s\"",
 			    ssn->username, ssn->password));
@@ -288,8 +276,10 @@ request_login(session **ssnptr, const char *server, const char *port, const
 abort:
 	close_connection(ssn);
 fail:
-	session_destroy(ssn);
-	ssn = NULL;
+	if (!*ssnptr) {
+		session_destroy(ssn);
+		ssn = NULL;
+	}
 
 	return -1;
 }
