@@ -12,6 +12,7 @@ typedef struct session {
 	const char *sslproto;	/* SSL protocol. */
 	const char *username;	/* User name. */
 	const char *password;	/* User password. */
+        const char *oauth2;     /* Oauth2 token */
 	int socket;		/* Socket. */
 	SSL *sslconn;		/* SSL connection. */
 	unsigned int protocol;	/* IMAP protocol.  Currently IMAP4rev1 and
@@ -21,7 +22,7 @@ typedef struct session {
 		char *prefix;	/* Namespace prefix. */
 		char delim;	/* Namespace delimiter. */
 	} ns;
-	const char *selected;	/* Selected mailbox. */
+	char *selected;	/* Selected mailbox. */
 } session;
 
 
